@@ -42,8 +42,6 @@ typedef struct _GtkSourceLanguageManager	GtkSourceLanguageManager;
 typedef struct _GtkSourceMarkAttributes		GtkSourceMarkAttributes;
 typedef struct _GtkSourceMark			GtkSourceMark;
 typedef struct _GtkSourcePrintCompositor	GtkSourcePrintCompositor;
-typedef struct _GtkSourceSearchContext		GtkSourceSearchContext;
-typedef struct _GtkSourceSearchSettings		GtkSourceSearchSettings;
 typedef struct _GtkSourceStyle			GtkSourceStyle;
 typedef struct _GtkSourceStyleScheme		GtkSourceStyleScheme;
 typedef struct _GtkSourceStyleSchemeManager	GtkSourceStyleSchemeManager;
